using System.Diagnostics;
using HackathonPreparing.ApiService;
using Microsoft.EntityFrameworkCore;
using Microsoft.OpenApi.Models;

var builder = WebApplication.CreateBuilder(args);


builder.Services.AddEndpointsApiExplorer();
builder.Services.AddSwaggerGen(c =>
{
    c.SwaggerDoc("v1", new OpenApiInfo {
        Title = "Weather Forecast API",
        Description = "Weather forecast API for the HackathonPreparing project.",
        Version = "v1" });
});

// Add service defaults & Aspire components.
builder.AddServiceDefaults();

// Add services to the container.
builder.Services.AddProblemDetails();


builder.AddNpgsqlDbContext<DatabaseContext>("prod", null,
    optionsBuilder => optionsBuilder.UseNpgsql(npgsqlBuilder =>
        npgsqlBuilder.MigrationsAssembly(typeof(Program).Assembly.GetName().Name)));

var app = builder.Build();


var logger = app.Services.GetRequiredService<ILogger<Program>>();






if (app.Environment.IsDevelopment())
{
    logger.LogWarning("!!!!!!! Call /ensure-created enpoint or /migrate if no db !!!!!!!!");
    app.UseSwagger();
    app.UseSwaggerUI(c =>
    {
        c.SwaggerEndpoint("/swagger/v1/swagger.json", "Weather Forecast API V1");
    });
    app.MapGet("/ensure-created", async (DatabaseContext db) => await db.Database.EnsureCreatedAsync());

    app.MapGet("/migrate", async (DatabaseContext db) => await db.Database.MigrateAsync());
}

// Configure the HTTP request pipeline.
app.UseExceptionHandler();




app.MapGet("/weatherforecast", async (DatabaseContext db) => await db.Forecasts.ToListAsync());

app.MapDefaultEndpoints();

app.Run();
